//------------------------------------------------------------------------------
//  Description:  This file contains functions that configure the ADS1298
//  
//------------------------------------------------------------------------------

/**************************************************************************************************************************************************
*                                 Included Headers                                                                                                *
**************************************************************************************************************************************************/
#include "include.h"
#include "ADS1298_Functions.h"

//------------------------------------------------------------------------------
//  void function(void)
//
//  DESCRIPTION:
//  
//  ARGUMENTS:
//      none
//------------------------------------------------------------------------------
volatile ADS1298_Status_Flags_type ADS1298_Status_Flags = {0x00,0x00,0x00,0x00};
/**************************************************************************************************************************************************
*                                 External Variables                                                                                              *
**************************************************************************************************************************************************/

void Set_ADS1298_Chip_Enable (void)                        // ADS1298 module uses GPIO as the SPI CS
{
    unsigned char i;
    SetBit(PORT_ADS_CS_DIR, ADS_CS);                         //Port 4.3 used as CS
    ResetBit(PORT_ADS_CS_OUT, ADS_CS);                       // Active low, 0 to select ADS
    for (i = 50; i > 0; i--);                             // Short Delay before invoking the SPI Port
}

void Clear_ADS1298_Chip_Enable (void)                      // ADS1298 uses GPIO for SPI CS
{
    unsigned char i;
    SetBit(PORT_ADS_CS_OUT, ADS_CS);                         // Active low, 1 to diselect ADS 
    SetBit(PORT_ADS_CS_DIR, ADS_CS);                       //Port 4.3 used as CS
    for (i = 50; i > 0; i--);     
}

void set_ADS1298_Start_High (void)
{
  SetBit(PORT_ADS_START_DIR, START);   
  SetBit(PORT_ADS_START_OUT, START);                     
}

void set_ADS1298_Start_Low (void)
{
  SetBit(PORT_ADS_START_DIR, START);   
  ResetBit(PORT_ADS_START_OUT, START);                     
}

void set_ADS1298_Power_Up (void)
{
  //1 means to power up ADS
  SetBit(PORT_ADS_POWER_DIR, POWER_UP);   
  SetBit(PORT_ADS_POWER_OUT, POWER_UP);                     
}

void set_ADS1298_Power_Down (void)
{
  //0 means to power down ADS
  SetBit(PORT_ADS_POWER_DIR, POWER_UP);   
  ResetBit(PORT_ADS_POWER_OUT, POWER_UP);                     
}

void set_ADS1298_Clock_Internal (void)
{
  //1 means using internal, power save
  SetBit(PORT_ADS_CLKSEL_DIR, INTERNAL_CLOCK);   
  SetBit(PORT_ADS_CLKSEL_OUT, INTERNAL_CLOCK);                     
}

void set_ADS1298_Clock_External (void)
{
  //0 means using external
  SetBit(PORT_ADS_CLKSEL_DIR, INTERNAL_CLOCK);   
  ResetBit(PORT_ADS_CLKSEL_OUT, INTERNAL_CLOCK);                     
}

void Power_On_Reset_ADS1298 (void)
{
    unsigned char t, w;
    unsigned int i;
    
      for (t = 0x20; t > 0; t--);             // Small Delay                   
      SetBit(PORT_ADS_RESET_OUT, ADS_RESET);        
      for (i = 0xFFFF; i > 0; i--)
        {
            for (w = 0x09; w > 0; w--);       // Large Delay
        }                                     //wait for (1s) oscillator to wake up  
    ResetBit(PORT_ADS_RESET_OUT, ADS_RESET);  // Reset Low
      for (t = 0x10; t > 0; t--);             // Small Delay   
    SetBit(PORT_ADS_RESET_OUT, ADS_RESET);    // Reset HIGH
      for (t = 0x90; t > 0; t--);             // about 18 Tclk       
}

void Hard_Reset_ADS1298_Off (void)
{
  //1 means NOT reset
  SetBit(PORT_ADS_RESET_DIR, ADS_RESET);   
  SetBit(PORT_ADS_RESET_OUT, ADS_RESET);                     
}

void Hard_Reset_ADS1298_On (void)
{
  //0 means  reset
  SetBit(PORT_ADS_RESET_DIR, ADS_RESET);   
  ResetBit(PORT_ADS_RESET_OUT, ADS_RESET);         
}

void Wake_Up_ADS1298 (void)
{
    Set_ADS1298_Chip_Enable (); 
	
    ADS1298_SPI_Data (WAKE_CONVERTER_FROM_SLEEP);                  // Send 0x02 to the ADS1298                                                      
}

void Put_ADS1298_In_Sleep (void)
{
    Set_ADS1298_Chip_Enable (); 
	 
    ADS1298_SPI_Data (PLACE_CONVERTER_IN_SLEEP_MODE);              // Send 0x04 to the ADS1298
}

void Soft_Reset_ADS1298 (void)
{
    Set_ADS1298_Chip_Enable (); 
	 
    ADS1298_SPI_Data (RESET_CONVERTER);                            // Send 0x06 to the ADS1298
}

void Soft_Start_ReStart_ADS1298 (void)
{
  //Start or restart conversion
    unsigned char i;
  	
    set_ADS1298_Start_Low ();                                                 // Start Pin LOW   
    for (i = 200; i > 0; i--);                                                  // Small Delay   
    ADS1298_SPI_Data (START_RESTART_CONVERSION);                   // Send 0x08 to the ADS1298
    Clear_ADS1298_Chip_Enable ();                                                       
}

void Soft_Stop_ADS1298 (void)
{
    //Stop conversion
    unsigned char i;
  	
    set_ADS1298_Start_Low ();                                                 // Start Pin LOW   
    for (i = 200; i > 0; i--);                                                  // Small Delay   
    Set_ADS1298_Chip_Enable (); 
    ADS1298_SPI_Data (STOP_CONVERSION);                            // Send 0x0A to the ADS1298
}

void Stop_Read_Data_Continuous (void)
{
    Set_ADS1298_Chip_Enable (); 
	
    ADS1298_SPI_Data (STOP_READ_DATA_CONTINUOUSLY);
}

void Start_Read_Data_Continuous (void)
{
    Set_ADS1298_Chip_Enable (); 
	
    ADS1298_SPI_Data (SET_READ_DATA_CONTINUOUSLY);
}

void enable_ADS1298_Interrupt (void)
{
    SetBit(PORT_INT_IE,ADS_DRDY); 
    //may want to put SPI interrupt in here 
}

void disable_ADS1298_Interrupt (void)
{
    ResetBit(PORT_INT_IE,ADS_DRDY); 
}

void enable_ADS1298_Conversion (void)
{    
    enable_ADS1298_Interrupt ();                                     // Interrupts must be enabled to transmit and receive data
    
    Start_Read_Data_Continuous ();                                   // Enable continuous conversion mode
    
    set_ADS1298_Start_High ();                                   // Pull START pin high
    
    ADS1298_Status_Flags.ADC_Data_Ready = CLEAR;                                // Clear Data Ready flag
}

unsigned char ADS1298_Read_Version (void)  
{
    unsigned char Version_ID = 18;
    ADS1298_SPI_Address_Byte_Count (READ_DEVICE_ID, SINGLE_BYTE);    		// Read Device ID, Single Byte the Part Number
    Version_ID = ADS1298_SPI_Data (DUMMY_DATA);                              // Send Dummy variable (0x55) to return the part number (Chip Select Cleared automatically)
    return Version_ID;
}  