//------------------------------------------------------------------------------
//  Description:  This file contains functions for communication between 
//                ADS 1298 and RF2500 using SPI.
//  
//------------------------------------------------------------------------------

/**************************************************************************************************************************************************
*                                 Included Headers                                                                                                *
**************************************************************************************************************************************************/
#include "include.h"
#include "ADS1298_SPI_Functions.h"

//------------------------------------------------------------------------------
//  void ADS1298_SPI_Address_Byte_Count (unsigned char Read_Write_Address, unsigned char Number_Of_Bytes)
//
//  DESCRIPTION:
//  
//  ARGUMENTS:
//      Read_Write_Address : address of the register to be read or written
//      Number_Of_Bytes    : 
//------------------------------------------------------------------------------

void ADS1298_SPI_Address_Byte_Count (unsigned char Read_Write_Address, unsigned char Number_Of_Bytes)
{ 
    Clear_ADS1298_Chip_Enable ();
  
    SPI_CTL0 &= ~UCCKPL;                //polarity
    SPI_CTL0 &= ~UCCKPH;                //phase
  
    Set_ADS1298_Chip_Enable ();         // Set the Chip ENABLE to start the SPI transaction

    SPI_IFR &= ~RX_IFG;                 // clear RX interrupt flag
    
    TX_BUF = Read_Write_Address;        // Transmit the Address payload
      
    while (!( SPI_IFR & RX_IFG ));      // stay in the loop while transmit is happening

    SPI_IFR &= ~TX_IFG;                  // clear TX interrupt flag
    SPI_IFR &= ~RX_IFG;                  // clear RX interrupt flag

    TX_BUF = Number_Of_Bytes;            // Transmit the Number of Bytes payload
    
    while (!( SPI_IFR & RX_IFG ));       // stay in the loop while received flag is clear

    SPI_IFR &= ~TX_IFG;                  // clear TX interrupt flag
    SPI_IFR &= ~RX_IFG;                  // clear RX interrupt flag
}

//------------------------------------------------------------------------------
//  unsigned char ADS1298_SPI_Data (unsigned char Data)
//
//  DESCRIPTION:
//  It is called after ADS1298_SPI_Address_Byte_Count since address of Read/Write
//  register is required, thus no CS disable/Enable
//
//  ARGUMENTS:
//      Data : Data or SPI_Address command can be sent using this parameter
//------------------------------------------------------------------------------

unsigned char ADS1298_SPI_Data (unsigned char Data)  
{
    SPI_CTL0 &= ~UCCKPL;                  //
    SPI_CTL0 &= ~UCCKPH;
    
    SPI_IFR &= ~RX_IFG;                  // clear RX interrupt flag
    
    TX_BUF = Data;                       // Send the data sitting at the pointer Data to the TX Buffer
    
    while (!( SPI_IFR & RX_IFG ));

    SPI_IFR &= ~TX_IFG;                  // clear TX interrupt flag
    SPI_IFR &= ~RX_IFG;                  // clear RX interrupt flag
    
    unsigned char i;
    for (i = 50; i > 0; i--);                                                  // Small Delay   
    
    Clear_ADS1298_Chip_Enable ();        // Clear the Chip ENABLE to terminate the SPI transaction
    
    return RX_BUF;                       // Return Status Data or Requested Read Data
}

//------------------------------------------------------------------------------
//  unsigned char ADS1298_SPI_Channel_Data (unsigned char Dummy_Data)
//
//  DESCRIPTION: 
//  for reading channel data, since there are continuous data 
//  coming in, so clear chip enable is omitted in this case for speed
//  
//  ARGUMENTS:
//      Dummy_Data: this function is usually called for asking data from ADS1298
//                  thus no meaningful data is needed to sent
//------------------------------------------------------------------------------

unsigned char ADS1298_SPI_Channel_Data (unsigned char Dummy_Data) 
{                                                                               
    SPI_IFR &= ~RX_IFG;                  // clear RX interrupt flag

    TX_BUF = Dummy_Data;                 // Send the 8 bit data to the TX Buffer

    while (!( SPI_IFR & RX_IFG )) ;

    SPI_IFR &= ~TX_IFG;                  // clear TX interrupt flag
    SPI_IFR &= ~RX_IFG;                  // clear RX interrupt flag

    return RX_BUF;                       // Return Status Data or Requested Read Data
} 
