#include "msp430x22x4.h"

//                           MSP430F2274
//                       -------------------
//                   /|\|                   |
//        ADS1298     | |                   |              C2500
//    -------------   --|RST                |/|\       ------------- /|\
//   |             |    |               XIN |-| /|\   |         GDO2|-| /|\
//   |             |    |               XOUT|----|    |         GDO0|----| 
//   |        DAISY|--->|(P5) P2.2 DAISY    |         |             | |  | 
//   |         DRDY|--->|(P6) P2.3 DRDY     |         |             | |  | 
//   |           CS|<---|(P7) P2.4 ADS CS   |         |             |  
//   |       CLKSEL|<---|(P8) P4.3 CLKSEL   |         |             | 
//   |        START|<---|(P9) P4.4 START    |         |             | 
//   |        ~PWND|<---|(P10)P4.5 ~PWDN    |         |             |
//   |        RESET|<---|(P11)P4.6 RESET    |         |             | 
//   |             |    |                   |         |             | 
//   |             |    |(P17)P3.0/UCB0STE  |-------->|CSn          |
//   |          DIN|<---|(P18)P3.1/UCB0SIMO |-------->|SI           |
//   |         DOUT|--->|(P15)P3.2/UCB0SOMI |<--------|SO(GDO1)     |
//   |         SCLK|<---|(P16)P3.3/UCB0CLK  |-------->|SCLK         |
//   |             |    |                   |         |             |
//   |             |    |               P1.0|---> LED
//   |             |    |               P1.1|---> LED

// REGISTER AND FLAG DEFINITIONS
#define RX_BUF    UCB0RXBUF
#define TX_BUF    UCB0TXBUF
#define RX_IFG    UCB0RXIFG
#define TX_IFG    UCB0TXIFG
#define SPI_IFR   IFG2 
#define SPI_CTL0  UCB0CTL0
#define SPI_CTL1  UCB0CTL1
#define SPI_BR0   UCB0BR0
#define SPI_BR1   UCB0BR1
#define SPI_B0_Rx_IER UCB0RXIFG
#define SPI_B0_Tx_IER UCB0TXIFG
#define SPI_B0_Rx_IE  BIT2
#define SPI_B0_Tx_IE  BIT3

// PORT DEFINITIONS 
#define PORT_LED_DIR    P1DIR      
#define PORT_LED_OUT    P1OUT

#define PORT_ADS_DAISY_OUT    P2OUT 
#define PORT_ADS_DAISY_DIR    P2DIR 

#define PORT_ADS_DRDY_OUT    P2OUT //DRDRY generates interrupt
#define PORT_ADS_DRDY_DIR    P2DIR 

#define PORT_ADS_CS_DIR    P2DIR 
#define PORT_ADS_CS_OUT    P2OUT 

#define PORT_ADS_CLKSEL_DIR    P4DIR 
#define PORT_ADS_CLKSEL_OUT    P4OUT 

#define PORT_ADS_START_DIR    P4DIR 
#define PORT_ADS_START_OUT    P4OUT 

#define PORT_ADS_POWER_DIR    P4DIR 
#define PORT_ADS_POWER_OUT    P4OUT 

#define PORT_ADS_RESET_OUT    P4OUT 
#define PORT_ADS_RESET_DIR    P4DIR 

#define PORT_SPI_DIR    P3DIR 
#define PORT_SPI_SEL    P3SEL 

#define PORT_INT_IN     P2IN //interrupt
#define PORT_INT_OUT    P2OUT 
#define PORT_INT_DIR    P2DIR 
#define PORT_INT_IE     P2IE 
#define PORT_INT_IES    P2IES 
#define PORT_INT_IFG    P2IFG 
#define PORT_INT_VECTOR PORT2_VECTOR 
 
// PIN DEFINITIONS 
#define GREEN_LED       1
#define RED_LED         0

#define ADS_DRDY	3
#define ADS_CS          4

#define INTERNAL_CLOCK  3
#define START	        4
#define POWER_UP        5
#define ADS_RESET       6

#define PIN_INT         BIT3 //interrupt
#define PIN_MOSI        BIT1 
#define PIN_MISO        BIT2 
#define PIN_SCK         BIT3 



