//------------------------------------------------------------------------------
//  Description:  This file contains functions for initialization of ADS1298
//  
//------------------------------------------------------------------------------

/**************************************************************************************************************************************************
*                                 Included Headers                                                                                                *
**************************************************************************************************************************************************/
#include "include.h"
#include "initialization.h"

//------------------------------------------------------------------------------
//  void init_MSP430_Com_IO(void)
//
//  DESCRIPTION:
//  Initialize the SPI and data ready interrupt connection bewteen MSP430 and ADS1298
//
//  ARGUMENTS:
//      none
//------------------------------------------------------------------------------
void init_MSP430_Com_IO (void)
{
  //Clock setup 
  BCSCTL1 = CALBC1_1MHZ;                       // Set DCO to calibrated 1MHz
  DCOCTL = CALDCO_1MHZ;
  
  //future:PUT ADS1298 CS pin setup here

  //SPI portocol setup
  UCB0CTL1 |= UCSWRST;                     // **Disable USCI state machine** 

  SPI_CTL0 |= UCMSB | UCMST | UCSYNC;     // 3-pin, 8-bit SPI mstr, MSB 1st
  SPI_CTL1 |= UCSSEL_2;                     // SMCLK
  SPI_BR0 = 0x02;                           // Divide (BR0+BR1x256) = 1Mhz/2=0.5MHz
  SPI_BR1 = 0;
    
  //Setup SPI Master Port
  PORT_SPI_SEL |= PIN_MOSI | PIN_MISO | PIN_SCK;   // P3.3,2 USCI_B0 option select
  PORT_SPI_DIR |= PIN_MOSI | PIN_SCK;                            // P3.0 output direction	

  //Disable CC2500 onboard
  PORT_SPI_DIR |= BIT0;
  P3OUT |= BIT0;
  
  //PORT_SPI_DIR &= ~PIN_MISO;
  
  UCB0CTL1 &= ~UCSWRST;                     // **Initialize USCI state machine**
  
  //IE2 |= UCB0RXIE | UCB0TXIE;             //Enable USCI_B Rx/Tx interrupt 
    
  //DRDY interrupt port enable setup
  PORT_INT_DIR &= ~PIN_INT;                       // Direction = input
  PORT_INT_IES |= PIN_INT;                            // Generate interrupt on Hi to Lo edge 
  PORT_INT_IFG &= ~PIN_INT;                       // Clear interrupt flag 
  PORT_INT_IE |= PIN_INT;                         // INT pin interrupt enabled 
}

//------------------------------------------------------------------------------
//  void init_ADS1298_IO(void)
//
//  DESCRIPTION:
//  Initialize the relavant I/O connected bewteen MSP430 and ADS1298
//
//  ARGUMENTS:
//      none
//------------------------------------------------------------------------------
void init_ADS1298_IO (void)
{
  set_ADS1298_Power_Down ();        // Power Down Pin (ACTIVE LOW)               
  Hard_Reset_ADS1298_On ();         // RESET Pin (ACTIVE LOW)        
  set_ADS1298_Start_Low ();         
  set_ADS1298_Clock_External ();
  Set_ADS1298_Chip_Enable ();       //to set the pin to Low
}

//------------------------------------------------------------------------------
//  void init_ADS1298(void)
//
//  DESCRIPTION:
//  Power up ADS1298 and set the initial configuration 
//
//  ARGUMENTS:
//      none
//------------------------------------------------------------------------------
void init_ADS1298 (void)
{

  init_MSP430_Com_IO ();
   
  enable_ADS1298_Interrupt ();  
  
  init_ADS1298_IO (); 
   
  set_ADS1298_Clock_Internal (); //use internal clock, energy save
  
  set_ADS1298_Power_Up (); 
   
  Power_On_Reset_ADS1298 (); 
  
  Stop_Read_Data_Continuous ();   
  
  ADS1298_SPI_Address_Byte_Count (WRITE_CONFIG_3_REGISTER,SINGLE_BYTE);
  ADS1298_SPI_Data (0xC0);            //Enable and use internal 2.4 reference voltage 
  
  ADS1298_SPI_Address_Byte_Count (WRITE_CONFIG_1_REGISTER, SINGLE_BYTE);    		
  ADS1298_SPI_Data (0x24);       //Low power mode 1kSPS with clock output
  //ADS1298_SPI_Data (0x04);       //Low power mode 1kSPS with no clock output
  //ADS1298_SPI_Data (0xA4);       //high power mode 1kSPS with clock output
  
  ADS1298_SPI_Address_Byte_Count (WRITE_CONFIG_2_REGISTER,SINGLE_BYTE);
  ADS1298_SPI_Data (0x00);  
  
  ADS1298_SPI_Address_Byte_Count (WRITE_CHANNEL_1_SET_REGISTER,SINGLE_BYTE);
  ADS1298_SPI_Data (0x60);          // Normal operation, Gain 12, Normal Channel input 
  
  Soft_Stop_ADS1298 (); //??
  
  disable_ADS1298_Interrupt ();
}