// FILE INFO *******************************************************************
//
//                           MSP430F2274
//                       -------------------
//                   /|\|                   |
//        ADS1298     | |                   |              C2500
//    -------------   --|RST                |/|\       ------------- /|\
//   |             |    |               XIN |-| /|\   |         GDO2|-| /|\
//   |             |    |               XOUT|----|    |         GDO0|----| 
//   |        DAISY|--->|(P5) P2.2 DAISY    |         |             | |  | 
//   |         DRDY|--->|(P6) P2.3 DRDY     |         |             | |  | 
//   |           CS|<---|(P7) P2.4 ADS CS   |         |             |  
//   |       CLKSEL|<---|(P8) P4.3 CLKSEL   |         |             | 
//   |        START|<---|(P9) P4.4 START    |         |             | 
//   |        ~PWND|<---|(P10)P4.5 ~PWDN    |         |             |
//   |        RESET|<---|(P11)P4.6 RESET    |         |             | 
//   |             |    |                   |         |             | 
//   |             |    |(P17)P3.0/UCB0STE  |-------->|CSn          |
//   |          DIN|<---|(P18)P3.1/UCB0SIMO |-------->|SI           |
//   |         DOUT|--->|(P15)P3.2/UCB0SOMI |<--------|SO(GDO1)     |
//   |         SCLK|<---|(P16)P3.3/UCB0CLK  |-------->|SCLK         |
//   |             |    |                   |         |             |
//   |             |    |               P1.0|---> LED
//   |             |    |               P1.1|---> LED
//
// Aim:
// Use 3 wire SPI to control ADS1298
// -----------------------------------------------------------------------------


// DEVICE HEADERS *************************************************************
// 
// Standard 430 IO headers
//#include "io430.h"
//#include "in430.h"

// Headers for controlling the ADS1298
#include "include.h" 

// -----------------------------------------------------------------------------

#define ADS1298_DATA_LENGTH 27		//216bits/8bits = 27 bytes
#define Num_of_channel      1
#define Payload_size_byte   (1+Num_of_channel)*3 //24 bits status, 24 bits data for each channel

//DEVICE DEFINIIONS

/**************************************************************************************************************************************************
*                                 Global Variables                                                                                              *
**************************************************************************************************************************************************/
INT8 ADS1298_Data [ADS1298_DATA_LENGTH]; // data from ADS1298
unsigned char Channel_DATA = 0;
unsigned char version = 0;
BYTE i, j, w;
BYTE dummy;
// -----------------------------------------------------------------------------


// EXTERNAL VARIABLES **********************************************************
extern volatile ADS1298_Status_Flags_type ADS1298_Status_Flags; 

// MAIN CODE *******************************************************************
void main( void )
{
    
  // Initalise MSP430 - setup power management, watchdog, system clock, UART, interrupts, ...
  // ***************************************************************************

  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer
  
  //Check board work
  SetBit(PORT_LED_DIR, GREEN_LED);
  SetBit(PORT_LED_OUT, GREEN_LED);
  
  init_ADS1298 ();
  
  //--------------------------------------------------------------------------- 
  enable_ADS1298_Conversion ();
  
  while (1)
  {     
//      ADS1298_SPI_Address_Byte_Count (WRITE_CONFIG_2_REGISTER,SINGLE_BYTE);
//  ADS1298_SPI_Data (0x00);  
      unsigned char IDnum = 0;
      IDnum = ADS1298_Read_Version ();
      unsigned char w = 0;
      w = IDnum + 1;
  }
}

#pragma vector=PORT_INT_VECTOR 
__interrupt void Port_INT_ISR(void) 
{
  //Once there is a data, interrupt is generated     
  if (PORT_INT_IN & PIN_INT)              
  {
    PORT_INT_IFG &= ~PIN_INT;                          // CLEAR ISR Flag
    ADS1298_Status_Flags.ADC_Data_Ready = SET;
  }
}
